==> CoolWorld-0.1.tar.gz: CoolWorld-0.1/setup.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from distutils.core import setup

setup(

    name="CoolWorld",

    version="0.1",     # must be PEP 440 compliant by now!

    packages=["CoolWorld"],
    requires=[],
    description="CoolWorld - Simplified Gaming Model",
    author="Raphaël SEBAN",
    author_email="motus@laposte.net",
    maintainer="Raphaël SEBAN",
    maintainer_email="motus@laposte.net",
    url="https://github.com/tarball69/CoolWorld",
    download_url="https://github.com/tarball69/CoolWorld/releases",
    keywords=["simple", "simplified", "game", "gaming", "model",
    "world", "items"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Other Environment",
        "Environment :: MacOS X",
        "Environment :: Win32 (MS Windows)",
        "Environment :: X11 Applications",
        "Intended Audience :: Developers",
        "License :: OSI Approved",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Topic :: Games/Entertainment",
    ],
    license="Licensed under the MIT License.",
    long_description="""

CoolWorld - Simplified Gaming Model
-----------------------------------

CoolWorld is a **Python3** gaming library based on the concept of one
world containing many world items, all interacting one with another.

It supports only the essentials for making a world go playing with
external GUI libs such as Tkinter, PyGObject (GTK+), PySide, Pygame,
Pyglet, PySDL2 and so on.

This project is **freefullware** oriented (see below).


NEW in v0.1
-----------

* first release - all is new!


Freefullware
------------

What is a freefullware?

A **freefullware** is a new kind of software:

* Free as in Freedom;
* Free of charge (gratis);
* Ad-free (no advertisement at all);
* Donate-free (no 'Donate' button at all);
* 100% virus-free;
* no counterpart at all;
* really absolutely free.

Just get it and enjoy.

That's all, folks!
"""

) # end setup

==> CoolWorld-0.2.tar.gz: CoolWorld-0.2/setup.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from distutils.core import setup

setup(

    name="CoolWorld",

    version="0.2",     # must be PEP 440 compliant by now!

    packages=["CoolWorld"],
    requires=[],
    description="CoolWorld - Simplified Gaming Model",
    author="Raphaël SEBAN",
    author_email="motus@laposte.net",
    maintainer="Raphaël SEBAN",
    maintainer_email="motus@laposte.net",
    url="https://github.com/tarball69/CoolWorld",
    download_url="https://github.com/tarball69/CoolWorld/releases",
    keywords=["simple", "simplified", "game", "gaming", "model",
    "world", "items"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Other Environment",
        "Environment :: MacOS X",
        "Environment :: Win32 (MS Windows)",
        "Environment :: X11 Applications",
        "Intended Audience :: Developers",
        "License :: OSI Approved",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Topic :: Games/Entertainment",
    ],
    license="Licensed under the MIT License.",
    long_description="""

CoolWorld - Simplified Gaming Model
-----------------------------------

CoolWorld is a **Python3** gaming library based on the concept of one
world containing many world items, all interacting one with another.

It supports only the essentials for making a world go playing with
external GUI libs such as Tkinter, PyGObject (GTK+), PySide, Pygame,
Pyglet, PySDL2 and so on.

This project is **freefullware** oriented.


Freefullware
------------

What is a freefullware?

A **freefullware** is a new kind of software:

* Free as in Freedom;
* Free of charge (gratis);
* Ad-free (no advertisement at all);
* Donate-free (no 'Donate' button at all);
* 100% virus-free;
* no counterpart at all;
* really absolutely free.

Just get it and enjoy.

That's all, folks!
"""

) # end setup
